@@ -1,8 +1,10 @@
 #!/usr/bin/python
 # -*- coding: UTF-8 -*-
+import datetime
 import os.path
 
 import akshare as ak
+import mootdx.utils.holiday as mooUtils
 import pandas
 from mootdx.quotes import Quotes
 from tqdm import tqdm
@@ -47,11 +49,47 @@ class DataHandler:
         # ]
         zxg_csv = self.__path + '/zxg.csv'
         self.__stock_list = pandas.read_csv(zxg_csv)
-        #print(self.__stock_list)
+        # print(self.__stock_list)
 
         # 标准市场
         self.__client = Quotes.factory(market='std', multithread=True, heartbeat=True)
 
+    def apply(self, func_name: str, func) -> pandas.DataFrame:
+        total = len(self.__stock_list)
+        print("自选股[%s]处理, 共计[%d]:" % (func_name, total))
+        values = enumerate(self.__stock_list.values)
+        pbar = tqdm(values, total=total)
+        df = pandas.DataFrame()
+        for key, value in pbar:
+            # if key == 2:
+            #     break
+
+            code = value[1][2:]
+            name = value[2]
+            try:
+                pbar.set_description_str("[%s]进行中" % code)
+                s = func(code, name)
+                #df = df.append(s, ignore_index=True)
+                df1 = pandas.DataFrame([s])
+                df = pandas.concat([df, df1], ignore_index=True)
+            except ValueError:
+                pass
+            finally:
+                pbar.set_description_str("[%s]完成" % code)
+        pbar.close()
+        print("自选股[%s], 处理完成." % func_name)
+        return df
+
+    def holiday(self, dt: datetime):
+        """
+        判断datetime是否假日
+        :param dt:
+        :return:
+        """
+        # date = dt.fromtimestamp("%Y-%m-%d")
+        date = dt.strftime("%Y-%m-%d")
+        return mooUtils.holiday(date)
+
     def __kline(self, code):
         """
         获取全量历史K线数据
@@ -92,9 +130,9 @@ class DataHandler:
             return None
         df = pandas.read_csv(filename)
         # 选择列, 是为了改变表头
-        df = df[["日期","开盘","收盘","最高","最低","成交量","成交额"]]
+        df = df[["日期", "开盘", "收盘", "最高", "最低", "成交量", "成交额"]]
         # 变更表头
-        df.columns=['date', 'open', 'close', 'high', 'low', 'volume', 'amount']
+        df.columns = ['date', 'open', 'close', 'high', 'low', 'volume', 'amount']
         # 更正排序
         df['date'] = pandas.to_datetime(df['date'])
         df.set_index('date', inplace=True)
@@ -122,9 +160,9 @@ class DataHandler:
         values = enumerate(self.__stock_list.values)
         pbar = tqdm(values, total=total)
         for key, value in pbar:
-            #print('key:', key, ', value: ', value)
+            # print('key:', key, ', value: ', value)
             code = value[1][2:]
-            #print("code:%s" % code)
+            # print("code:%s" % code)
             pbar.set_description_str("同步[%s]进行中" % code)
             data = self.__finance(code=code)
             data.to_csv(self.__info_cn + '/' + code + '.csv', index=False)
@@ -143,4 +181,4 @@ class DataHandler:
         if not os.path.exists(filename):
             return
         df = pandas.read_csv(filename)
-        return df
\ No newline at end of file
+        return df
