@@ -1,5 +1,8 @@
 #!/usr/bin/python
 # -*- coding: UTF-8 -*-
+"""
+最基础的工具
+"""
 
 # A_YI:=100000000;
 # 亿:A_YI;
@@ -10,7 +13,9 @@ def ZTBL(code: str):
     """
     涨停比例, 只支持A股
 
-    30 68开头的个股涨停比例20%, 其余10%
+    .. note::
+      30 68开头的个股涨停比例20%, 其余10%
+
     :param code:
     :return:
     """
@@ -21,6 +26,15 @@ def ZTBL(code: str):
     else:
         return 0.1
 
+def ZTPRICE(close, ztbl):
+    """
+    计算涨停价
+    :param close:
+    :param ztbl:
+    :return:
+    """
+    return close * (1+ztbl)
+
 # 停牌:DYNAINFO(8)<=0;
 # ST股:NAMELIKE('ST') OR NAMELIKE('*ST') OR NAMELIKE('S');
 # 真阳线:CLOSE>REF(CLOSE,1);
